from orbitkit.file_extractor.extractor import FileExtractor


class FileExtractorAudio(FileExtractor):
    def __init__(self):
        super().__init__()

    def extract(self):
        file_obj = self.file_obj
        pass
